#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 libxml
version:              0.1.1
visibility:           public
id:                   libxml-0.1.1-3kWuDUQNYiOJz4bhlpzLfJ
key:                  libxml-0.1.1-3kWuDUQNYiOJz4bhlpzLfJ
license:              BSD-3-Clause
copyright:            2006, Lemmih
maintainer:           Lemmih (lemmih@gmail.com)
author:               Lemmih (lemmih@gmail.com)
synopsis:             Binding to libxml2
description:
    Minimal binding to libxml2. Additional functions will be added when needed.

category:             XML
abi:                  97e8b831482b71a03e38c5557bbf08db
exposed:              True
exposed-modules:
    Text.XML.LibXML Text.XML.LibXML.Internals Text.XML.LibXML.Parser
    Text.XML.LibXML.Tree Text.XML.LibXML.Types

import-dirs:          /usr/lib/ghc-8.10.5/site-local/libxml-0.1.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/libxml-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/libxml-0.1.1
hs-libraries:         HSlibxml-0.1.1-3kWuDUQNYiOJz4bhlpzLfJ
extra-libraries:      xml2
include-dirs:         /usr/include/libxml2
includes:             libxml/xmlIO.h libxml/xmlmemory.h
depends:              base-4.14.2.0 bytestring-0.10.12.0 mtl-2.2.2
haddock-interfaces:   /usr/share/doc/haskell-libxml/html/libxml.haddock
haddock-html:         /usr/share/doc/haskell-libxml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

